@@ -16,8 +16,7 @@ Siebel::Srvrmgr::Daemon - super class for sessions with Siebel srvrmgr program
 
 This is a super class, and alone it does not provide any functionaly to use srvrmgr to send commands and process returned data.
 
-The "private" method C<_setup_commands> must be overrided by subclasses of it or commands will not be sent to srvrmgr (the currently implementation C<warn>s 
-about that). 
+The "private" method C<_setup_commands> must be overrided by subclasses of it or commands will not be sent to C<srvrmgr>. 
 
 Logging of this class can be enabled by using L<Siebel::Srvrmgr> logging feature.
 
@@ -38,16 +37,19 @@ Implementation details are reserved to subclasses of Siebel::Srvrmgr::Daemon: be
 
 use Moose;
 use Siebel::Srvrmgr::Regexes qw(SIEBEL_ERROR);
-use POSIX;
+use Siebel::Srvrmgr::ListParser;
 use Siebel::Srvrmgr;
 use Scalar::Util qw(weaken);
 use Config;
-use Carp qw(longmess);
 use Siebel::Srvrmgr::Types;
+use Fcntl ':flock';    # import LOCK_* constants
+use Config;
+use Carp;
+use File::Spec;
 
-our $SIG_INT   = 0;
-our $SIG_PIPE  = 0;
-our $SIG_ALARM = 0;
+my $SIG_INT   = 0;
+my $SIG_PIPE  = 0;
+my $SIG_ALARM = 0;
 
 $SIG{INT}  = sub { $SIG_INT   = 1 };
 $SIG{PIPE} = sub { $SIG_PIPE  = 1 };
@@ -307,10 +309,76 @@ Since this attribute should be defined during Daemon object instance, it is read
 
 has field_delimiter => ( is => 'ro', isa => 'Chr', reader => 'get_field_del' );
 
+=head2 has_lock
+
+Optional parameter.
+
+This is a boolean attribute (in the sense of Perl) that identifies if the L<Daemon> needs to use a lock or not. Default is false.
+
+Using a lock is useful to avoid two instances of the same C<Daemon> running. See also C<lock_dir> attribute.
+
+=cut
+
+has has_lock => ( is => 'ro', isa => 'Bool', default => 0 );
+
+=head2 lock_dir
+
+Optional parameter.
+
+This parameter is used to determine the location in the filesystem to create the lock file.
+
+Expects a string as parameter. The directory must be readable and writable to the user running the C<Daemon>.
+
+It defaults to the "home" directory of the user. The sense of "home" is the following as defined by the platform:
+
+This attribute is lazy and defined by the C<_define_lock_dir> "private" method.
+
+=over
+
+=item *
+
+Microsoft Windows: C<$ENV{HOMEDIR}>
+
+=item *
+
+UNIX-like: C<$ENV{HOME}>
+
+=back
+
+=cut
+
+has lock_dir => (
+    is      => 'rw',
+    isa     => 'Str',
+    reader  => 'get_lock_dir',
+    writer  => 'set_lock_dir',
+    lazy    => 1,
+    builder => '_define_lock_dir'
+);
+
+=pod
+
+=head2 cmd_stack
+
+This is an array reference with the stack of commands to be executed. It is maintained automatically by the class, so the attribute is read-only.
+
+=cut
+
+has cmd_stack => (
+    isa    => 'ArrayRef',
+    is     => 'ro',
+    writer => '_set_cmd_stack',
+    reader => 'get_cmd_stack'
+);
+
 =pod
 
 =head1 METHODS
 
+=head2 get_cmd_stack
+
+Returns the content of the attribute C<cmd_stack>.
+
 =head2 get_field_del
 
 Getter for the C<field_delimiter> attribute.
@@ -435,8 +503,39 @@ sub reset_retries {
 
 }
 
-# for better security
-sub _check_cmd {
+=head2 check_cmd
+
+This methods expects as parameter a string representing a C<srvrmgr> command.
+
+The command will be checked and if considered insecure, an exception will be raised.
+
+Commands considered secure are:
+
+=over
+
+=item *
+
+load preferences
+
+=item *
+
+list <anything>
+
+=item *
+
+exit
+
+=item *
+
+set delimiter
+
+=back
+
+This method is also used internally through the C<_setup_commands> method.
+
+=cut
+
+sub check_cmd {
 
     my $self = shift;
     my $cmd  = shift;
@@ -448,6 +547,7 @@ sub _check_cmd {
     confess("Insecure command from command stack [$cmd]. Execution aborted")
       unless ( ( $cmd =~ /^load/ )
         or ( $cmd =~ /^list/ )
+        or ( $cmd =~ /^set\sdelimiter\s[[:graph:]]/ )
         or ( $cmd =~ /^exit/ ) );
 
     return 1;
@@ -493,15 +593,20 @@ sub shift_commands {
 
 =head2 run
 
-This is the method used to execute commands in srvrmgr program and must be overrided by subclasses of Siebel::Srvrmgr::Daemon or an exception will
-be generated.
+This is the method used to execute commands in srvrmgr program and must be overrided by subclasses of Siebel::Srvrmgr::Daemon.
+Subclasses should invoke L<Moose> C<super> to when doing override because this implementation will apply lock control when appropriate.
 
 =cut
 
 sub run {
 
-    confess
-      'This method must be overrided by subclasses of Siebel::Srvrmgr::Daemon';
+    my $self = shift;
+
+    if ( $self->has_lock ) {
+
+        $self->_create_lock;
+
+    }
 
 }
 
@@ -596,54 +701,97 @@ sub _define_params {
     push( @params, '/s', $self->get_server() )
       if ( defined( $self->get_server() ) );
 
-# :WORKAROUND:06/08/2013 21:05:32:: if a perlscript will be executed (like for automated testing of this distribution)
-# then the perl interpreter must be part of the command path to avoid calling cmd.exe (in Microsoft Windows)
+# :WORKAROUND:06/08/2013 21:05:32:: if a perl script will be executed (like for automated testing of this distribution)
+# then the perl interpreter must be part of the command path to avoid calling cmd.exe in Microsoft Windows
     unshift( @params, $Config{perlpath} ) if ( $self->use_perl() );
 
     return \@params;
 
 }
 
+=head2 get_lock_file
+
+Returns the complete path to the lock file as a string.
+
+=cut
+
+sub get_lock_file {
+
+    my $self = shift;
+
+    my $filename = $self->blessed;
+    $filename =~ s/\:{2}/_/g;
+
+    return File::Spec->catfile( $self->get_lock_dir, ( $filename . '.lock' ) );
+
+}
+
+our $adm_60070    = qr/^SBL-ADM-60070.*/;
+our $adm_02043    = qr/^SBL-ADM-02043.*/;
+our $adm_02071    = qr/^SBL-ADM-02071.*/;
+our $adm_02049    = qr/^SBL-ADM-02049.*/;
+our $adm_02751    = qr/^SBL-ADM-02751.*/;
+our $siebel_error = SIEBEL_ERROR;
+
 sub _check_error {
 
-    my $self   = shift;
-    my $line   = shift;
-    my $logger = shift;
+    my $self    = shift;
+    my $content = shift;
+    my $logger  = shift;
 
     weaken($logger);
 
-    # caught an error, until now all they are fatal
-    $logger->warn( "Caught [$line]:" . longmess() );
+    if ( ref($content) eq 'ARRAY' ) {
 
-    if ( $line =~ SIEBEL_ERROR ) {
+        foreach my $line ( @{$content} ) {
 
-      SWITCH: {
+# :WORKAROUND:22-09-2014 14:02:27:: to avoid multiple methods calls, the verifications
+# were duplicated (copy an paste)
+            if ( $line =~ $siebel_error ) {
 
-            if ( $line =~ /^SBL-ADM-60070.*/ ) {
+              SWITCH: {
 
-                $logger->warn(
-                    'Trying to get additional information from next line')
-                  if ( $logger->is_warn() );
-                return 1;
-            }
+                    if ( $line =~ $adm_60070 ) {
 
-            if ( $line =~ /^SBL-ADM-02043.*/ ) {
-                $logger->logdie('Could not find the Siebel Server');
-            }
+                        $logger->warn(
+'Trying to get additional information from next line'
+                        ) if ( $logger->is_warn() );
+                        return 1;
+                    }
 
-            if ( $line =~ /^SBL-ADM-02071.*/ ) {
-                $logger->logdie('Could not find the Siebel Enterprise');
-            }
+                    if ( $line =~ $adm_02043 ) {
+                        $logger->logdie('Could not find the Siebel Server');
+                    }
 
-            if ( $line =~ /^SBL-ADM-02049.*/ ) {
-                $logger->logdie('Generic error');
-            }
+                    if ( $line =~ $adm_02071 ) {
+                        $logger->logdie('Could not find the Siebel Enterprise');
+                    }
+
+                    if ( $line =~ $adm_02049 ) {
+                        $logger->logdie('Generic error');
+                    }
+
+                    if ( $line =~ $adm_02751 ) {
+                        $logger->logdie('Unable to open file');
+                    }
+                    else {
+                        $logger->logdie(
+                            "Unknown error [$line], aborting execution");
+                    }
+
+                }
 
-            if ( $line =~ /^SBL-ADM-02751.*/ ) {
-                $logger->logdie('Unable to open file');
             }
             else {
-                $logger->logdie('Unknown error, aborting execution');
+
+                $logger->debug(
+"Got $line. Since it doesn't look like a Siebel error, I will try to keep running"
+                ) if ( $logger->is_debug );
+
+                $logger->warn($content);
+
+                return 1;
+
             }
 
         }
@@ -651,8 +799,52 @@ sub _check_error {
     }
     else {
 
-        $logger->warn(
-            'Since this is not a Siebel error, I will try to keep running');
+        if ( $content =~ $siebel_error ) {
+
+          SWITCH: {
+
+                if ( $content =~ $adm_60070 ) {
+
+                    $logger->warn(
+                        'Trying to get additional information from next line')
+                      if ( $logger->is_warn() );
+                    return 1;
+                }
+
+                if ( $content =~ $adm_02043 ) {
+                    $logger->logdie('Could not find the Siebel Server');
+                }
+
+                if ( $content =~ $adm_02071 ) {
+                    $logger->logdie('Could not find the Siebel Enterprise');
+                }
+
+                if ( $content =~ $adm_02049 ) {
+                    $logger->logdie('Generic error');
+                }
+
+                if ( $content =~ $adm_02751 ) {
+                    $logger->logdie('Unable to open file');
+                }
+                else {
+                    $logger->logdie(
+                        "Unknown error [$content], aborting execution");
+                }
+
+            }
+
+        }
+        else {
+
+            $logger->debug(
+"Got $content. Since it doesn't look like a Siebel error, I will try to keep running"
+            ) if ( $logger->debug );
+
+            $logger->warn($content);
+
+            return 1;
+
+        }
 
     }
 
@@ -681,6 +873,12 @@ sub DEMOLISH {
 
     $self->_my_cleanup($logger);
 
+    if ( $self->has_lock ) {
+
+        $self->_del_lock($logger);
+
+    }
+
     $logger->info('Cleanup is finished');
 
     if ( $logger->is_warn() ) {
@@ -698,19 +896,158 @@ sub DEMOLISH {
 
 }
 
+=head1 CONSTANTS
+
+The following constants are available in this class:
+
+=over
+
+=item LOCK_EX
+
+=item LOCK_NB
+
+=back
+
+All of them from the L<Fcntl> module.
+
+=cut
+
+sub _create_lock {
+
+    my $self = shift;
+
+    my $logger = Siebel::Srvrmgr->gimme_logger( ref($self) );
+    weaken($logger);
+
+    my $lock_file = $self->get_lock_file;
+
+    if ( -e $lock_file ) {
+
+        open( my $in, '<', $lock_file )
+          or $logger->logdie("Cannot read $lock_file: $!");
+        flock( $in, LOCK_EX | LOCK_NB )
+          or $logger->logdie("Could not get exclusive lock on $lock_file: $!");
+        local $/ = undef;
+        my $pid = <$in>;
+        close($in);
+
+        $logger->logdie(
+            "Previous executing is still running (PID $pid), cannot execute")
+          if ( $pid != $$ );
+
+    }
+    else {
+
+        open( my $out, '>', $lock_file )
+          or $logger->logdie("Cannot create $lock_file: $!");
+        flock( $out, LOCK_EX | LOCK_NB )
+          or $logger->logdie("Could not get exclusive lock on $lock_file: $!");
+        print $out $$;
+        close($out);
+
+    }
+
+}
+
+sub _del_lock {
+
+    my $self      = shift;
+    my $logger    = shift;
+    my $lock_file = $self->get_lock_file;
+
+    if ( -e $lock_file ) {
+
+        unlink($lock_file)
+          or $logger->logdie("Could not remove $lock_file: $!");
+
+    }
+    else {
+
+        $logger->warn(
+            'Could not find lock file to remove before program termination');
+
+    }
+
+}
+
 sub _my_cleanup {
 
     return 1;
 
 }
 
+sub _define_lock_dir {
+
+	my $lock_dir = undef;
+	
+	CASE: {
+
+		if ( $Config{osname} =~ /^linux$/i ) {
+
+			$lock_dir = $ENV{HOME};
+			last CASE;
+
+		}
+
+		if ( $Config{osname} =~ /^aix$/i ) {
+
+			$lock_dir = $ENV{HOME};
+			last CASE;
+
+		}
+
+		if ( $Config{osname} =~ /^hpux$/i ) {
+
+			$lock_dir = $ENV{HOME};
+			last CASE;
+
+		}
+
+		if ( $Config{osname} =~ /^mswin32$/i ) {
+
+			if (defined( $ENV{HOMEDIR} ) ) {
+			
+				$lock_dir = $ENV{HOMEDIR};
+			
+			} else {
+			
+				$lock_dir = $ENV{USERPROFILE};
+			
+			}
+			
+			last CASE;
+
+		}
+
+		if ( $Config{osname} =~ /^solaris$/i ) {
+
+			$lock_dir = $ENV{HOME};
+			last CASE;
+
+		}
+		else {
+
+			confess "don't know what to do with $Config{osname}";
+
+		}
+	
+	}
+	
+	confess "could not defined a lock_dir for $Config{osname}" unless(defined($lock_dir));
+	
+	return $lock_dir;
+
+}
+
 sub _setup_commands {
 
     my $self = shift;
 
-    confess(
-'_setup_commands from Siebel::Srvrmgr::Daemon must be overrided by subclass '
-          . ref($self) );
+    foreach my $cmd ( @{ $self->get_commands } ) {
+
+        $self->check_cmd( $cmd->get_command() );
+
+    }
 
 }
 
@@ -744,11 +1081,15 @@ L<POSIX>
 
 L<Siebel::Srvrmgr::Daemon::Command>
 
+=item *
+
+L<Fcntl>
+
 =back
 
 =head1 AUTHOR
 
-Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
