@@ -89,7 +89,8 @@ L<Siebel::Srvrmgr::ListParser>
 
 my %table_mapping = (
     'list_comp'        => ['Tabular::ListComp', qr/^list\scomps?$/],
-    'list_params'      => ['Tabular::ListParams', qr/list\sparam(eter)?s?(\s(\w+\s)?(for\sserver\s\w+)?(\sfor\s((comp(nent)?)|named\ssubsystem|task)\s\w+)?)?/],
+    'set_delimiter'    => ['Set', qr/^set\sdelimiter/],
+    'list_params'      => ['Tabular::ListParams', qr/list\s(advanced\s)?param(eter)?s?(\s(\w+\s)?(for\sserver\s\w+)?(\sfor\s((comp(nent)?)|named\ssubsystem|task)\s\w+)?)?/],
     'list_comp_def'    => ['Tabular::ListCompDef', qr/list\scomp\sdefs?(\s\w+)?/],
     'greetings'        => ['Enterprise', CONN_GREET],
     'list_comp_types'  => ['Tabular::ListCompTypes', qr/list\scomp(nent)?\stypes?$/],
