@@ -59,6 +59,10 @@ sub runs : Tests(+10) {
     $test->SUPER::runs();
 
     ok( $test->{daemon}->run(), 'run method executes successfuly' );
+
+    my $lock_file = $test->{daemon}->get_lock_file;
+    $test->{lock_file} = $lock_file;    # see the_last_run
+
     is( $test->{daemon}->get_child_runs(),
         1, 'get_child_runs returns the expected number' );
 
@@ -114,7 +118,6 @@ sub runs_much_more : Tests(60) {
         for ( 1 .. 60 ) {
 
             ok( $test->{daemon}->run(), 'run method executes successfuly' );
-			sleep(5);
 
         }
 
@@ -122,33 +125,6 @@ sub runs_much_more : Tests(60) {
 
 }
 
-#sub runs_blocked : Test() {
-#
-#    my $test = shift;
-#
-#  TODO: {
-#
-#        local $TODO = 'Usage of alarm must be reviewed';
-#
-#        $test->{daemon}->set_commands(
-#            [
-#                Siebel::Srvrmgr::Daemon::Command->new(
-#                    command => 'list blockme',
-#                    action => 'Dummy'   # this one is to get the initial message
-#                ),
-#                Siebel::Srvrmgr::Daemon::Command->new(
-#                    command => 'list blockme',
-#                    action =>
-#                      'Dummy'    # this one is to get the "list blockme" message
-#                ),
-#            ]
-#        );
-#        dies_ok { $test->{daemon}->run() } 'run method fail due timeout';
-#
-#    }
-#
-#}
-
 sub runs_with_stderr : Test(4) {
 
     my $test = shift;
@@ -212,7 +188,7 @@ sub _poke_child {
 
 }
 
-sub terminator : Tests(4) {
+sub the_termination : Tests(4) {
 
     my $test   = shift;
     my $logger = Siebel::Srvrmgr->gimme_logger( $test->class() );
